import React, { useContext, useEffect, useState } from 'react';
import { Headline, CommonMenuList,LoadingCircle, ContentInfo, NavList, NavItem } from '../component/mod';

import { Box, Paper, Link, useMediaQuery, Portal, List, ListItem, ListItemIcon, Tooltip, ListItemText } from '@material-ui/core';
import {useTheme, makeStyles, Theme} from '@material-ui/core/styles';
import ContentAccessor,{QueryListOption, Document} from '../accessor/document';
import {Link as RouterLink} from 'react-router-dom';
import {toQueryString} from '../accessor/util';

import {useLocation} from 'react-router-dom';
import { QueryStringToMap } from '../accessor/util';

const useStyles = makeStyles((theme:Theme)=>({
    root:{
        display:"grid",
        gridGap: theme.spacing(4),
    },
}));

export type GalleryProp = {
    option?:QueryListOption;
    diff:string;
};
type GalleryState = {
    documents:Document[]|undefined;
}

export const GalleryInfo = (props: GalleryProp)=>{
    const [state,setState]= useState<GalleryState>({documents:undefined});
    useEffect(()=>{
        const load = (async ()=>{
            const c = await ContentAccessor.findList(props.option);
            //todo : if c is undefined, retry to fetch 3 times. and show error message.
            setState({documents:c});
        })
        load();
    },[props.diff]);
    const classes = useStyles();
    const queryString = toQueryString(props.option||{});

    if(state.documents === undefined){
        return (<LoadingCircle/>);
    }
    else{
        return (<Box className={classes.root}>{
            state.documents.map(x=>{
                return (<ContentInfo document={x} key={x.id} 
                    gallery={`/search?${queryString}`} short/>);
        })
        }
        </Box>);
    }
}

export const Gallery = ()=>{
    const location = useLocation();
    const query = QueryStringToMap(location.search);
    const menu_list = CommonMenuList({url:location.search});
    
    return (<Headline menu={menu_list}>
        <GalleryInfo diff={location.search} option={query}></GalleryInfo>
    </Headline>)
}